// 药耗监测
import PageContent from '@/components/PageContent';
import PageTitle from '@/components/PageTitle';
import { getPendingList } from '@/services/message';
import { UnityAction } from '@/utils/utils';
import { useParams, useRequest } from '@umijs/max';
import dayjs from 'dayjs';
import styles from './backlog.less';

const CostComparison = () => {
  const { projectId } = useParams();
  const { data, loading } = useRequest(getPendingList, {
    defaultParams: [{ project_id: projectId }],
  });
  const handleClick = (item) => {
    if (item.type === 0) {
      // task
      UnityAction.sendMsg('OpenTaskModal', `mandate_id=${item.origin_id}`);
    } else {
      // order
      UnityAction.sendMsg(
        'OpenWorkOrderModal',
        `order_id=${item.origin_id}&order_type=${item.origin_type}`,
      );
    }
  };
  return (
    <PageContent closeable={false}>
      <PageTitle onReturn={() => UnityAction.sendMsg('menuItem', '首页')}>
        待办事项
      </PageTitle>

      <div className={styles.backlog}>
        <div>
          {data?.map((item) => (
            <div
              key={item.connect}
              className={`${styles.item} ${
                item.type == 0 ? styles.task : styles.order
              }`}
              onClick={(e) => {
                e.stopPropagation();
                handleClick(item);
              }}
            >
              <div className={styles.createTime}>
                {dayjs(item.time).format('MM-DD HH:mm')}
              </div>
              <div className={styles.point} />
              <div className={styles.titleCon}>
                <div className={styles.titleText}>{item.title}</div>
              </div>

              <div className={styles.bottomCon}>
                {item.content}
                <div className={styles.btn}>
                  {item.type == 0 ? '任务' : '工单'}详情
                </div>
              </div>
            </div>
          ))}
        </div>
      </div>
    </PageContent>
  );
};

export default CostComparison;
